@@ -7,6 +7,7 @@ use crate::ics02_client::events as ClientEvents;
 use crate::ics02_client::events::NewBlock;
 use crate::ics03_connection::events as ConnectionEvents;
 use crate::ics04_channel::events as ChannelEvents;
+use crate::ics04_channel::events::Attributes as ChannelAttributes;
 use crate::Height;
 use prost::alloc::fmt::Formatter;
 use std::fmt;
@@ -65,11 +66,11 @@ pub enum IbcEvent {
 }
 
 /// For use in debug messages
-pub struct VecIbcEvents(pub Vec<IbcEvent>);
-impl fmt::Display for VecIbcEvents {
+pub struct PrettyEvents<'a>(pub &'a [IbcEvent]);
+impl<'a> fmt::Display for PrettyEvents<'a> {
     fn fmt(&self, f: &mut Formatter<'_>) -> fmt::Result {
         writeln!(f, "events:")?;
-        for v in &self.0 {
+        for v in self.0 {
             writeln!(f, "\t{}", v)?;
         }
         Ok(())
@@ -130,7 +131,10 @@ pub fn from_tx_response_event(height: Height, event: &tendermint::abci::Event) -
 
 impl IbcEvent {
     pub fn to_json(&self) -> String {
-        serde_json::to_string(self).unwrap()
+        match serde_json::to_string(self) {
+            Ok(value) => value,
+            Err(_) => format!("{:?}", self), // Fallback to debug printing
+        }
     }
 
     pub fn height(&self) -> Height {
@@ -183,6 +187,16 @@ impl IbcEvent {
             _ => unimplemented!(),
         }
     }
+
+    pub fn channel_attributes(&self) -> Option<&ChannelAttributes> {
+        match self {
+            IbcEvent::OpenInitChannel(ev) => Some(ev.attributes()),
+            IbcEvent::OpenTryChannel(ev) => Some(ev.attributes()),
+            IbcEvent::OpenAckChannel(ev) => Some(ev.attributes()),
+            IbcEvent::OpenConfirmChannel(ev) => Some(ev.attributes()),
+            _ => None,
+        }
+    }
 }
 
 #[derive(Debug, Clone, Deserialize, Serialize)]
