@@ -1,3 +1,5 @@
+use std::num::ParseIntError;
+
 use anomaly::{BoxError, Context};
 use thiserror::Error;
 
@@ -62,6 +64,12 @@ pub enum Kind {
     #[error("invalid raw client consensus state")]
     InvalidRawConsensusState,
 
+    #[error("invalid client id in the update client message")]
+    InvalidMsgUpdateClientId,
+
+    #[error("invalid raw client consensus state: the height field is missing")]
+    MissingHeight,
+
     #[error("invalid client identifier: validation error: {0}")]
     InvalidClientIdentifier(ValidationKind),
 
@@ -74,6 +82,9 @@ pub enum Kind {
     #[error("invalid height result")]
     InvalidHeightResult,
 
+    #[error("cannot convert into a `Height` type from string {0}")]
+    HeightConversion(String, ParseIntError),
+
     #[error("invalid address")]
     InvalidAddress,
 
