@@ -23,8 +23,14 @@ pub trait Msg: Clone {
     fn get_sign_bytes(self) -> Vec<u8> {
         let mut buf = Vec::new();
         let raw_msg: Self::Raw = self.into();
-        prost::Message::encode(&raw_msg, &mut buf).unwrap();
-        buf
+        match prost::Message::encode(&raw_msg, &mut buf) {
+            Ok(()) => buf,
+            // Severe error that cannot be recovered.
+            Err(e) => panic!(
+                "Cannot encode the proto message {:?} into a buffer due to underlying error: {}",
+                raw_msg, e
+            ),
+        }
     }
 
     fn validate_basic(&self) -> Result<(), ValidationError> {
